# Generated by Django 4.2.5 on 2023-09-29 20:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_state_keeper', '0001_initial'),
    ]

    operations = [
        migrations.DeleteModel(
            name='BackupUpload',
        ),
        migrations.AlterField(
            model_name='backuppackaging',
            name='paths_to_gather',
            field=models.TextField(default='db.sqlite3', max_length=1000),
        ),
    ]
